function y = mfunlist
%MFUNLIST Special functions for MFUN.
%   The following special functions are listed in alphabetical order
%   according to the third column. n denotes an integer argument, 
%   x denotes a real argument, and z denotes a complex argument. For 
%   more detailed descriptions of the functions, including any
%   argument restrictions, see the Reference Manual, or use MHELP.
%
%bernoulli      n       Bernoulli Numbers
%bernoulli      n,z     Bernoulli Polynomials
%BesselI        x1,x    Bessel Function of the First Kind
%BesselJ        x1,x    Bessel Function of the First Kind
%BesselK        x1,x    Bessel Function of the Second Kind
%BesselY        x1,x    Bessel Function of the Second Kind
%Beta           z1,z2   Beta Function
%binomial       x1,x2   Binomial Coefficients
%EllipticF -    z,k     Incomplete Elliptic Integral, First Kind
%EllipticK -    k       Complete Elliptic Integral, First Kind
%EllipticCK -   k       Complementary Complete Integral, First Kind
%EllipticE -    k       Complete Elliptic Integrals, Second Kind
%EllipticE -    z,k     Incomplete Elliptic Integrals, Second Kind
%EllipticCE -   k       Complementary Complete Elliptic Integral, Second Kind
%EllipticPi -   nu,k    Complete Elliptic Integrals, Third Kind
%EllipticPi -   z,nu,k  Incomplete Elliptic Integrals, Third Kind
%EllipticCPi -  nu,k    Complementary Complete Elliptic Integral, Third Kind
%erfc           z       Complementary Error Function
%erfc           n,z     Complementary Error Function's Iterated Integrals
%Ci             z       Cosine Integral
%dawson         x       Dawson's Integral
%Psi            z       Digamma Function
%dilog          x       Dilogarithm Integral
%erf            z       Error Function 
%euler          n       Euler Numbers
%euler          n,z     Euler Polynomials
%Ei             x       Exponential Integral
%Ei             n,z     Exponential Integral
%FresnelC       x       Fresnel Cosine Integral 
%FresnelS       x       Fresnel Sine Integral 
%GAMMA          z       Gamma Function 
%harmonic       n       Harmonic Function
%Chi            z       Hyperbolic Cosine Integral
%Shi            z       Hyperbolic Sine Integral
%GAMMA          z1,z2   Incomplete Gamma Function
%W              z       Lambert's W Function
%W              n,z     Lambert's W Function
%lnGAMMA        z       Logarithm of the Gamma function
%Li             x       Logarithmic Integral
%Psi            n,z     Polygamma Function
%Ssi            z       Shifted Sine Integral
%Si             z       Sine Integral
%Zeta           z       (Riemann) Zeta Function
%Zeta           n,z     (Riemann) Zeta Function
%Zeta           n,z,x   (Riemann) Zeta Function
%
%       Orthogonal Polynomials (Extended Symbolic Math Toolbox only)
%T      n,x             Chebyshev of the First Kind
%U      n,x             Chebyshev of the Second Kind
%G      n,x1,x          Gegenbauer
%H      n,x             Hermite
%P      n,x1,x2,x       Jacobi
%L      n,x             Laguerre
%L      n,x1,x          Generalized Laguerre
%P      n,x             Legendre
%
%   See also MFUN, MHELP.

%   Copyright 1993-2002 The MathWorks, Inc. 
%   $Revision: 1.14 $  $Date: 2002/04/15 03:13:53 $

help mfunlist
